@@ -1,6 +1,6 @@
-package Config::MVP::Error;
+package Config::MVP::Error 2.200013;
 # ABSTRACT: common exceptions class
-$Config::MVP::Error::VERSION = '2.200012';
+
 use Moose;
 
 has message => (
@@ -45,15 +45,27 @@ Config::MVP::Error - common exceptions class
 
 =head1 VERSION
 
-version 2.200012
+version 2.200013
+
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
