@@ -1,6 +1,6 @@
-package Config::MVP::Reader;
+package Config::MVP::Reader 2.200013;
 # ABSTRACT: object to read config from storage into an assembler
-$Config::MVP::Reader::VERSION = '2.200012';
+
 use Moose;
 
 use Config::MVP::Assembler;
@@ -126,7 +126,7 @@ Config::MVP::Reader - object to read config from storage into an assembler
 
 =head1 VERSION
 
-version 2.200012
+version 2.200013
 
 =head1 SYNOPSIS
 
@@ -143,6 +143,18 @@ file) and convert that data into instructions to a L<Config::MVP::Assembler>,
 which will in turn convert them into a L<Config::MVP::Sequence>, the final
 product.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 add_cwd_to_lib
@@ -199,11 +211,11 @@ entirely generic one.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
