@@ -1,6 +1,6 @@
-package Config::MVP::Section;
+package Config::MVP::Section 2.200013;
 # ABSTRACT: one section of an MVP configuration sequence
-$Config::MVP::Section::VERSION = '2.200010';
+
 use Moose 0.91;
 
 use Class::Load 0.17 ();
@@ -302,13 +302,25 @@ Config::MVP::Section - one section of an MVP configuration sequence
 
 =head1 VERSION
 
-version 2.200010
+version 2.200013
 
 =head1 DESCRIPTION
 
 For the most part, you can just consult L<Config::MVP> to understand what this
 class is and how it's used.
 
+=head1 PERL VERSION
+
+This module should work on any version of perl still receiving updates from
+the Perl 5 Porters.  This means it should work on any version of perl released
+in the last two to three years.  (That is, if the most recently released
+version is v5.40, then this module should work on both v5.40 and v5.38.)
+
+Although it may work on older versions of perl, no guarantee is made that the
+minimum required version will not be increased.  The version may be increased
+for any reason, and there is no promise that patches will be accepted to lower
+the minimum required perl.
+
 =head1 ATTRIBUTES
 
 =head2 name
@@ -400,11 +412,11 @@ installed.  By default, it throws an exception.
 
 =head1 AUTHOR
 
-Ricardo Signes <rjbs@cpan.org>
+Ricardo Signes <cpan@semiotic.systems>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Ricardo Signes.
+This software is copyright (c) 2022 by Ricardo Signes.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
